@@ -815,29 +815,43 @@ class Builder(Update):
         """
         Получить пакеты ebuild которых изменились
 
-        Перебираем все пакеты из var/db/pkg (а именно получаем поля из
-        environment.bz2)
-        и сравниваем эти поля с полями из metadata/md5-cache для пакетов.
+        Перебираем все пакеты из var/db/pkg и сравниваем metadata/md5-cache для пакетов.
         Таким образом в список не попадут те пакеты, у которых RDEPEND и DEPEND
         были изменены динамически например при исправлении "автомагии"
         """
         var_db_path = path.join(builder_path, 'var/db/pkg')
-        map_rep = {k: pathJoin(builder_path, v)
-                   for k, v in repository_data}
-        map_rep = self.repair_gentoo_repo(map_rep, builder_path)
 
         def rebuild_generator():
+            pkg_path = self.clVars.Get("builder.cl_builder_pkg_cache_path")
             for pkg in InstalledPackageInfo.get_install_packages(var_db_path):
-                try:
-                    if pkg['repository'] not in map_rep:
-                        b = pkg['repository']
-                        yield pkg.atom
-                    elif pkg != EbuildInfo(pkg.atom,
-                                           map_rep[pkg['repository']]):
-                        a = EbuildInfo(pkg.atom, map_rep[pkg['repository']])
-                        yield pkg.atom
-                except EbuildInfoError:
-                    pass
+                old_hash = None
+                for repo in repository_data:
+                    if pkg.repository in repo:
+                        pkg.repository = repo
+                else:
+                    yield f'{pkg.category}/{pkg.pkg}'
+
+                path_to_repo = pathJoin(builder_path, pkg.repository)
+                path_to_file = pathJoin(path_to_repo, meta_suffix_path, pkg[0], pkg[1])
+                if not path.exists(path_to_file):
+                    continue
+                c = ConfigParser()
+                with open(path_to_file) as f:
+                    string = '[data]\n' + f.read()
+                    c.read_string(string)
+                md = hashlib.md5(str({'SLOT': c['data'].get('SLOT'),
+                                      'IUSE': c['data'].get('IUSE'),
+                                      'DEPEND': c['data'].get('DEPEND'),
+                                      'RDEPEND': c['data'].get('RDEPEND'),
+                                      'PDEPEND': c['data'].get('PDEPEND')}).encode('UTF-8'))
+                new_hash = md.hexdigest()
+                if path.exists(pathJoin(builder_path, pkg_path, meta_suffix_path, pkg[0], pkg[1])):
+                    with open(pathJoin(builder_path, pkg_path, meta_suffix_path, pkg[0], pkg[1])) as f:
+                        old_hash = f.read().strip()
+                with writeFile(pathJoin(builder_path, pkg_path, meta_suffix_path, pkg[0], pkg[1])) as f:
+                    f.write(md.hexdigest())
+                if old_hash and old_hash != new_hash:
+                    yield f'{pkg[0]}/{pkg[1]}'
 
         return ["=%s" % x for x in rebuild_generator()]
 
